from django.db import models
from django.forms import ModelForm, HiddenInput
from django import forms
from django.utils import timezone

#
# Models for WarpFood
# ToDo: FoodProduct Size not required
#

class FoodService(models.Model):
    name = models.CharField(max_length=250)
    phone = models.CharField(max_length=250)

    def __str__(self):
        return self.name

class FoodCategory(models.Model):
    name = models.CharField(max_length=250)

    def __str__(self):
        return self.name

class FoodProduct(models.Model):
    name = models.CharField(max_length=250)
    food_service = models.ForeignKey(FoodService, on_delete=models.CASCADE)
    food_category = models.ForeignKey(FoodCategory, on_delete=models.CASCADE)
    size = models.CharField(max_length=100, null=True)
    price = models.FloatField()

    def __str__(self):
        return self.name + " - " + self.size


class FoodSheet(models.Model):
    date = models.DateTimeField(default=timezone.now)
    food_service = models.ForeignKey(FoodService, on_delete=models.CASCADE)
    estimated_order_time = models.DateTimeField()
    closed = models.BooleanField(default=False)
    order_user = models.CharField(max_length=100, null=True)
    order_time = models.DateTimeField(null=True)


class FoodOrder(models.Model):
    sheet = models.ForeignKey(FoodSheet, on_delete=models.CASCADE)
    user = models.CharField(max_length=100,null=True)
    article = models.CharField(max_length=100, null=True)
    size = models.CharField(max_length=100, null=True)
    comment = models.CharField(max_length=100, null=True)
    price = models.FloatField()
    paid = models.BooleanField(default=False)


class FoodSheetForm(ModelForm):
    class Meta:
        model = FoodSheet
        fields = ['food_service', 'estimated_order_time']


class FoodOrderForm(ModelForm):
    comment = forms.CharField(required=False)

    class Meta:
        model = FoodOrder
        fields = ['sheet', 'user', 'article', 'size', 'comment', 'price', 'paid']
        widgets = {'paid': HiddenInput(), 'sheet': HiddenInput(), 'user': HiddenInput()}

class FoodOrderFormExt(ModelForm):
    comment = forms.CharField(required=False)

    class Meta:
        model = FoodOrder
        fields = ['sheet', 'user', 'article', 'size', 'comment', 'price', 'paid']
        widgets = {'sheet': HiddenInput(), 'paid': HiddenInput()}

class FoodServiceForm(ModelForm):
    class Meta:
        model = FoodService
        fields = ['name', 'phone']
